
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;
use Test::More;

# generated by Dist::Zilla::Plugin::Test::PodSpelling 2.006009
use Test::Spelling 0.12;
use Pod::Wordlist;


add_stopwords(<DATA>);
all_pod_files_spelling_ok( qw( bin lib  ) );
__DATA__
DROLSKY
DROLSKY's
Rolsky
Rolsky's
Andreas
Axel
Charset
Cribbs
ETag
Encodings
Erlang
Fayland
Gratz
Hartzell
JS
JavaScript
Luehrs
Marienborg
Oschwald
RESTful
Raynham
Sheehy
Sibley
Stevan
WebDAV
Webmachine
arity
charsets
fREW
webmachine
Little
stevan
Dave
autarch
Infinity
Interactive
Inc
andreas
Andrew
Nelson
anelson
Arthur
Schmidt
frioux
Carlos
Fernando
Avila
cafe
Lam
fayland
George
hartzell
Gregory
goschwald
Jesse
doy
John
SJ
Anderson
genehack
Mike
enquiries
mike
Nathan
Cutler
ncutler
Olaf
Alders
olaf
Thomas
tsibley
lib
Web
Machine
FSM
States
I18N
en
Manual
Resource
Util
BodyEncoding
ContentNegotiation
