
BEGIN {
  unless ($ENV{AUTHOR_TESTING}) {
    require Test::More;
    Test::More::plan(skip_all => 'these tests are for testing by the author');
  }
}

use strict;
use warnings;

# this test was generated with Dist::Zilla::Plugin::Test::EOL 0.18

use Test::More 0.88;
use Test::EOL;

my @files = (
    'lib/Web/Machine.pm',
    'lib/Web/Machine/FSM.pm',
    'lib/Web/Machine/FSM/States.pm',
    'lib/Web/Machine/I18N.pm',
    'lib/Web/Machine/I18N/en.pm',
    'lib/Web/Machine/Manual.pod',
    'lib/Web/Machine/Resource.pm',
    'lib/Web/Machine/Util.pm',
    'lib/Web/Machine/Util/BodyEncoding.pm',
    'lib/Web/Machine/Util/ContentNegotiation.pm',
    't/00-report-prereqs.dd',
    't/00-report-prereqs.t',
    't/001-basic.t',
    't/002-basic-content-type-handlers.t',
    't/003-request-class.t',
    't/010-resource-tests.t',
    't/010-resources/B10.pm',
    't/010-resources/B11.pm',
    't/010-resources/B12.pm',
    't/010-resources/B13.pm',
    't/010-resources/B3.pm',
    't/010-resources/B4.pm',
    't/010-resources/B5.pm',
    't/010-resources/B6.pm',
    't/010-resources/B7.pm',
    't/010-resources/B7b.pm',
    't/010-resources/B8.pm',
    't/010-resources/B8b.pm',
    't/010-resources/B8c.pm',
    't/010-resources/B8d.pm',
    't/010-resources/B9.pm',
    't/010-resources/C4.pm',
    't/010-resources/D5.pm',
    't/010-resources/E6.pm',
    't/010-resources/F6.pm',
    't/010-resources/F7.pm',
    't/010-resources/G11.pm',
    't/010-resources/H12.pm',
    't/010-resources/H7.pm',
    't/010-resources/H7b.pm',
    't/010-resources/H7c.pm',
    't/010-resources/H7d.pm',
    't/010-resources/H7e.pm',
    't/010-resources/H7f.pm',
    't/010-resources/I4.pm',
    't/010-resources/I4b.pm',
    't/010-resources/J18.pm',
    't/010-resources/K5.pm',
    't/010-resources/K5b.pm',
    't/010-resources/L17.pm',
    't/010-resources/L5.pm',
    't/010-resources/L5b.pm',
    't/010-resources/L7.pm',
    't/010-resources/M20.pm',
    't/010-resources/M20b.pm',
    't/010-resources/M5.pm',
    't/010-resources/M7.pm',
    't/010-resources/N11.pm',
    't/010-resources/N11b.pm',
    't/010-resources/N11c.pm',
    't/010-resources/N11d.pm',
    't/010-resources/N11e.pm',
    't/010-resources/N11f.pm',
    't/010-resources/N11g.pm',
    't/010-resources/N11h.pm',
    't/010-resources/N5.pm',
    't/010-resources/O14.pm',
    't/010-resources/O14b.pm',
    't/010-resources/O18.pm',
    't/010-resources/O18b.pm',
    't/010-resources/O18c.pm',
    't/010-resources/O18d.pm',
    't/010-resources/O18e.pm',
    't/010-resources/O18f.pm',
    't/010-resources/O20.pm',
    't/010-resources/O20b.pm',
    't/010-resources/O20c.pm',
    't/010-resources/P11.pm',
    't/010-resources/P11b.pm',
    't/010-resources/P11c.pm',
    't/010-resources/P11d.pm',
    't/010-resources/P11e.pm',
    't/010-resources/P3.pm',
    't/010-resources/P3b.pm',
    't/011-resource-500-logging.t',
    't/012-warning-no-etag.t',
    't/013-finish-request-logging.t',
    't/020-post-w-redirect.t',
    't/021-post-w-bypass-n11.t',
    't/022-body-encoding.t',
    't/030-streaming.t',
    't/031-streaming-push.t',
    't/300-content-negotiation-media-type.t',
    't/301-content-negotiation-language.t',
    't/302-content-negotiation-charset.t',
    't/303-content-negotiation-encoding.t',
    't/304-negotiation-match-media-type.t',
    't/400-bind-path.t',
    't/500-example-hello-word.t',
    't/501-example-env-resource.t',
    't/502-example-long-poll.t',
    't/600-yapc-talk-examples/000-basic.t',
    't/600-yapc-talk-examples/001-basic.t',
    't/600-yapc-talk-examples/002-basic.t',
    't/600-yapc-talk-examples/010-browser.t',
    't/600-yapc-talk-examples/011-browser.t',
    't/600-yapc-talk-examples/012-browser.t',
    't/600-yapc-talk-examples/020-auth.t',
    't/600-yapc-talk-examples/030-postback.t',
    't/600-yapc-talk-examples/031-postback-w-json.t',
    't/600-yapc-talk-examples/032-postback-w-auth.t',
    't/600-yapc-talk-examples/033-postback-w-hateoas.t',
    't/600-yapc-talk-examples/100-add-caching.t',
    't/600-yapc-talk-examples/110-service-unavailable.t',
    't/600-yapc-talk-examples/120-bind-path.t',
    't/600-yapc-talk-examples/130-tracing-header.t',
    't/700-malformed-auth-bug.t',
    't/701-content-type-is-actionpack.t',
    't/author-00-compile.t',
    't/author-eol.t',
    't/author-no-tabs.t',
    't/author-pod-spell.t',
    't/author-test-version.t',
    't/release-cpan-changes.t',
    't/release-pod-coverage.t',
    't/release-pod-linkcheck.t',
    't/release-pod-syntax.t',
    't/release-portability.t',
    't/release-synopsis.t'
);

eol_unix_ok($_, { trailing_whitespace => 1 }) foreach @files;
done_testing;
